import { Server } from 'socket.io'
import { TSocket } from '#utilities/types'
import { Item } from '@prisma/client'
import characterRepository from '#repositories/characterRepository'
import { gameMasterLogger } from '#utilities/logger'
import itemRepository from '#repositories/itemRepository'

interface IPayload {}

export default class ItemListEvent {
  constructor(
    private readonly io: Server,
    private readonly socket: TSocket
  ) {}

  public listen(): void {
    this.socket.on('gm:item:list', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: Item[]) => void): Promise<void> {
    const character = await characterRepository.getById(this.socket.characterId as number)
    if (!character) {
      gameMasterLogger.error('gm:item:list error', 'Character not found')
      return callback([])
    }

    if (character.role !== 'gm') {
      gameMasterLogger.info(`User ${character.id} tried to list items but is not a game master.`)
      return callback([])
    }

    // get all items
    const items = await itemRepository.getAll()
    callback(items)
  }
}